"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ensureRelativePath = exports.getSWCTransformReactOpts = exports.getBabelPresetReactOpts = exports.getBaseTransformReactOpts = exports.getIsLTRReact17 = exports.addSourceMappingUrl = void 0;
const utils_1 = require("@umijs/utils");
const path_1 = __importDefault(require("path"));
function addSourceMappingUrl(code, loc) {
    return (code +
        '\n//# sourceMappingURL=' +
        path_1.default.basename(loc.replace(/\.(jsx|tsx?)$/, '.js')));
}
exports.addSourceMappingUrl = addSourceMappingUrl;
function getIsLTRReact17(pkg) {
    const reactVer = Object.assign({}, pkg.dependencies, pkg.peerDependencies).react;
    return utils_1.semver.subset(reactVer, '>=17.0.0-0');
}
exports.getIsLTRReact17 = getIsLTRReact17;
function getBaseTransformReactOpts(pkg) {
    const reactVer = Object.assign({}, pkg.dependencies, pkg.peerDependencies).react;
    let opts = {};
    if (reactVer) {
        const isLTRReact17 = getIsLTRReact17(pkg);
        opts = {
            // force use production mode, to make sure dist of dev/build are consistent
            // ref: https://github.com/umijs/umi/blob/6f63435d42f8ef7110f73dcf33809e6cda750332/packages/babel-preset-umi/src/index.ts#L45
            development: false,
            // use legacy jsx runtime for react@<17
            runtime: isLTRReact17 ? 'automatic' : 'classic',
            ...(isLTRReact17 ? {} : { importSource: undefined }),
        };
    }
    return opts;
}
exports.getBaseTransformReactOpts = getBaseTransformReactOpts;
function getBabelPresetReactOpts(pkg) {
    return {
        ...getBaseTransformReactOpts(pkg),
    };
}
exports.getBabelPresetReactOpts = getBabelPresetReactOpts;
function getSWCTransformReactOpts(pkg) {
    return {
        ...getBaseTransformReactOpts(pkg),
    };
}
exports.getSWCTransformReactOpts = getSWCTransformReactOpts;
function ensureRelativePath(relativePath) {
    // prefix . for same-level path
    if (!relativePath.startsWith('.')) {
        relativePath = `./${relativePath}`;
    }
    return relativePath;
}
exports.ensureRelativePath = ensureRelativePath;
